@@ -1,7 +1,7 @@
 from pyvcam import pvc
 from pyvcam.camera import Camera
 name = "pyvcam"
-hwid = []
+hwid = ["software"]
 
 class instrument:
     def __init__(self,port):
