@@ -29,7 +29,7 @@ class InstrumentWrapper(param.Parameterized):
         self.reload_devices()
         self.button.on_click(self.reload_devices)
         devices = list(self.devices.keys())
-        if "software_software" in devices:
+        if "software" in devices:
             self.instrument_selected = "software_software"
         elif len(devices) > 0:
             self.instrument_selected = devices[0]
@@ -42,7 +42,7 @@ class InstrumentWrapper(param.Parameterized):
             for hwid in self.modules[module]["hwid"]:
                 if hwid == "software":
                     name = self.modules[module]["name"]
-                    self.devices[f"software_{name}"] = {"name": name, "hwid": "software", "serial_number": "software",
+                    self.devices[name] = {"name": name, "hwid": "software", "serial_number": "software",
                                                         "module": module, "port": "software"}
                 else:
                     for port in ports:
