@@ -1,7 +1,7 @@
 import elliptec
 
 name = "elliptec"
-hwid = []
+hwid = ["0403:6015"]
 
 
 def find_ports():
